@@ -41,13 +41,16 @@ using Banshee.ServiceStack;
 
 namespace Nereid
 {
-
     public class ViewContainer : VBox
     {
         private SearchEntry search_entry;
         private HBox header;
+        private Alignment header_align;
         private EventBox header_box;
+
+        private EventBox default_title_box;
         private Label title_label;
+        private HBox custom_title_box;
         private Banshee.ContextPane.ContextPane context_pane;
         private VBox footer;
 
@@ -63,22 +66,28 @@ namespace Nereid
 
         private void BuildHeader ()
         {
+            header_align = new Alignment (0.0f, 0.5f, 1.0f, 1.0f);
+            if (Hyena.PlatformDetection.IsMeeGo) {
+                header_align.RightPadding = 5;
+                header_align.TopPadding = 5;
+            }
+
             header = new HBox ();
             footer = new VBox ();
 
-            EventBox title_box = new EventBox ();
+            default_title_box = new EventBox ();
             title_label = new Label ();
             title_label.Xalign = 0.0f;
             title_label.Ellipsize = Pango.EllipsizeMode.End;
 
-            title_box.Add (title_label);
+            default_title_box.Add (title_label);
 
             // Show the source context menu when the title is right clicked
-            title_box.PopupMenu += delegate {
+            default_title_box.PopupMenu += delegate {
                 ServiceManager.Get<InterfaceActionService> ().SourceActions ["SourceContextMenuAction"].Activate ();
             };
 
-            title_box.ButtonPressEvent += delegate (object o, ButtonPressEventArgs press) {
+            default_title_box.ButtonPressEvent += delegate (object o, ButtonPressEventArgs press) {
                 if (press.Event.Button == 3) {
                     ServiceManager.Get<InterfaceActionService> ().SourceActions ["SourceContextMenuAction"].Activate ();
                 }
@@ -86,9 +95,12 @@ namespace Nereid
 
             header_box = new EventBox ();
 
+            custom_title_box = new HBox () { Visible = false };
+
             BuildSearchEntry ();
 
-            header.PackStart (title_box, true, true, 0);
+            header.PackStart (default_title_box, true, true, 0);
+            header.PackStart (custom_title_box, true, true, 0);
             header.PackStart (header_box, false, false, 0);
             header.PackStart (search_entry, false, false, 0);
 
@@ -107,10 +119,11 @@ namespace Nereid
                 }
             }
 
-            header.ShowAll ();
+            header_align.Add (header);
+            header_align.ShowAll ();
             search_entry.Show ();
 
-            PackStart (header, false, false, 0);
+            PackStart (header_align, false, false, 0);
             PackEnd (footer, false, false, 0);
 
             context_pane = new Banshee.ContextPane.ContextPane ();
@@ -146,6 +159,7 @@ namespace Nereid
             AddSearchFilter (TrackFilterType.None, String.Empty, Catalog.GetString ("Artist, Album, or Title"));
             AddSearchFilter (TrackFilterType.SongName, "title", Catalog.GetString ("Track Title"));
             AddSearchFilter (TrackFilterType.ArtistName, "artist", Catalog.GetString ("Artist Name"));
+            AddSearchFilter (TrackFilterType.AlbumArtist, "albumartist", Catalog.GetString ("Album Artist"));
             AddSearchFilter (TrackFilterType.AlbumTitle, "album", Catalog.GetString ("Album Title"));
             AddSearchFilter (TrackFilterType.Genre, "genre", Catalog.GetString ("Genre"));
             AddSearchFilter (TrackFilterType.Year, "year", Catalog.GetString ("Year"));
@@ -220,14 +234,35 @@ namespace Nereid
             }
         }
 
-        public HBox Header {
-            get { return header; }
+        public Alignment Header {
+            get { return header_align; }
         }
 
         public SearchEntry SearchEntry {
             get { return search_entry; }
         }
 
+        public void SetTitleWidget (Widget widget)
+        {
+            var child = custom_title_box.Children.Length == 0 ? null : custom_title_box.Children[0];
+            if (widget == child) {
+                return;
+            }
+
+            if (child != null) {
+                custom_title_box.Remove (child);
+            }
+
+            if (widget != null) {
+                widget.HeightRequest = search_entry.Allocation.Height;
+                widget.Show ();
+                custom_title_box.PackStart (widget, false, false, 0);
+            }
+
+            custom_title_box.Visible = widget != null;
+            default_title_box.Visible = widget == null;
+        }
+
         public ISourceContents Content {
             get { return content; }
             set {
