@@ -55,7 +55,7 @@ namespace Banshee.PlayQueue
 {
     public class PlayQueueSource : PlaylistSource, IBasicPlaybackController, IPlayQueue, IDBusExportable, IDisposable
     {
-        private static string special_playlist_name = "Play Queue";
+        private static string special_playlist_name = Catalog.GetString ("Play Queue");
 
         private ITrackModelSource prior_playback_source;
         private DatabaseTrackInfo current_track;
@@ -469,18 +469,23 @@ namespace Banshee.PlayQueue
 
         public override void ReorderSelectedTracks (int drop_row)
         {
-            // If the current_track is not playing, make the first pending unselected track the current one.
+            // If the current_track is not playing, dropping tracks may change it.
+            // If the selection is dropped above the current_track, the first pending
+            // of the dropped tracks (if any) will become the new current_track.
+            // If the tracks are dropped below the curren_track,
+            // the first pending track not in the selection will become current.
             if (current_track != null && !ServiceManager.PlayerEngine.IsPlaying (current_track)) {
                 int current_index = TrackModel.IndexOf (current_track);
+                bool above = drop_row <= current_index;
                 int new_index = -1;
                 for (int index = current_index; index < TrackModel.Count; index++) {
-                    if (!TrackModel.Selection.Contains (index)) {
+                    if (above == TrackModel.Selection.Contains (index)) {
                         new_index = index;
                         break;
                     }
                 }
-                if (new_index != current_index) {
-                    SetCurrentTrack (new_index == -1 ? null : TrackModel[new_index] as DatabaseTrackInfo);
+                if (new_index != current_index && new_index >= 0) {
+                    SetCurrentTrack (TrackModel[new_index] as DatabaseTrackInfo);
                 }
             }
 
@@ -540,7 +545,7 @@ namespace Banshee.PlayQueue
             return ((IBasicPlaybackController)this).Next (false, true);
         }
 
-        bool IBasicPlaybackController.Next (bool restart, bool userRequested)
+        bool IBasicPlaybackController.Next (bool restart, bool changeImmediately)
         {
             if (current_track != null && ServiceManager.PlayerEngine.CurrentTrack == current_track) {
                 int index = TrackModel.IndexOf (current_track) + 1;
@@ -551,9 +556,9 @@ namespace Banshee.PlayQueue
                 ServiceManager.PlaybackController.Source = PriorSource;
                 if (was_playing) {
                     ServiceManager.PlaybackController.PriorTrack = prior_playback_track;
-                    ServiceManager.PlaybackController.Next (restart, userRequested);
+                    ServiceManager.PlaybackController.Next (restart, changeImmediately);
                 } else {
-                    if (!userRequested) {
+                    if (!changeImmediately) {
                         ServiceManager.PlayerEngine.SetNextTrack ((TrackInfo)null);
                     }
                     ServiceManager.PlayerEngine.Close ();
@@ -561,7 +566,7 @@ namespace Banshee.PlayQueue
                 return true;
             }
 
-            if (userRequested) {
+            if (changeImmediately) {
                 ServiceManager.PlayerEngine.OpenPlay (current_track);
             } else {
                 ServiceManager.PlayerEngine.SetNextTrack (current_track);
